Sphinx theme based on Solarized colour palette
==============================================

This is a `Sphinx <http://sphinx-doc.org>`_ theme forked from the builtin
*Haiku* theme. It uses the colour palette from
`Solarized <https://ethanschoonover.com/solarized/>`_ by Ethan Schoonover.

The overall theme uses the light Solarized variant, with all the code
sections being displayed through the Python package
`pygments-style-solarized <https://pypi.org/project/pygments-style-solarized/>`_
in the dark Solarized variant.
